========================
Team and repository tags
========================

.. image:: https://governance.openstack.org/tc/badges/tripleo-common.svg
    :target: https://governance.openstack.org/tc/reference/tags/index.html

.. Change things from this point on

==============
tripleo-common
==============

A common library for TripleO workflows.

* Free software: Apache license
* Documentation: https://docs.openstack.org/tripleo-common/latest/
* Source: http://opendev.org/openstack/tripleo-common
* Bugs: https://bugs.launchpad.net/tripleo-common
* Release notes: https://docs.openstack.org/releasenotes/tripleo-common
